@@ -157,7 +157,7 @@ L<PAR>
 
 =head1 AUTHORS
 
-Audrey Tang E<lt>autrijus@autrijus.orgE<gt>
+Audrey Tang E<lt>cpan@audreyt.orgE<gt>
 
 L<http://par.perl.org/> is the official PAR website.  You can write
 to the mailing list at E<lt>par@perl.orgE<gt>, or send an empty mail to
@@ -168,7 +168,7 @@ Please submit bug reports to E<lt>bug-par@rt.cpan.orgE<gt>.
 =head1 COPYRIGHT
 
 Copyright 2002, 2003, 2004, 2005, 2006 by Audrey Tang
-E<lt>autrijus@autrijus.orgE<gt>.
+E<lt>cpan@audreyt.orgE<gt>.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
