@@ -141,6 +141,12 @@ This is just a zip file beginning with the magic string "C<PK\003\004>".
 
 =item * Ending section
 
+The pre-computed cache name.  A pack('Z40') string of the value of -T 
+(--tempcache) or the hash of the file, followed by C<\0CACHE>.  The hash
+of the file is calculated with L<Digest::SHA>, L<Digest::SHA1>, or 
+L<Digest::MD5>.  If none of those modules is available, the C<mtime> of
+the file is used.
+
 A pack('N') number of the total length of FILE and PAR sections,
 followed by a 8-bytes magic string: "C<\012PAR.pm\012>".
 
@@ -290,7 +296,6 @@ my ($start_pos, $data_pos);
 
         die "Bootstrapping failed: cannot find $module!\n";
     }, @INC);
-    # }}}
 
     # Now load all bundled files {{{
 
@@ -784,7 +789,7 @@ sub _par_init_env {
     for (qw( SPAWNED TEMP CLEAN DEBUG CACHE PROGNAME ARGC ARGV_0 ) ) {
         delete $ENV{'PAR_'.$_};
     }
-    for (qw/ TEMP CLEAN DEBUG /) {
+    for (qw/ TMPDIR TEMP CLEAN DEBUG /) {
         $ENV{'PAR_'.$_} = $ENV{'PAR_GLOBAL_'.$_} if exists $ENV{'PAR_GLOBAL_'.$_};
     }
 
@@ -826,7 +831,7 @@ require PAR;
 unshift @INC, \&PAR::find_par;
 PAR->import(@par_args);
 
-die qq(Can't open perl script "$progname": No such file or directory\n)
+die qq(par.pl: Can't open perl script "$progname": No such file or directory\n)
     unless -e $progname;
 
 do $progname;
@@ -849,7 +854,7 @@ L<PAR>, L<PAR::Dist>, L<parl>, L<pp>
 
 =head1 AUTHORS
 
-Audrey Tang E<lt>autrijus@autrijus.orgE<gt>
+Audrey Tang E<lt>cpan@audreyt.orgE<gt>
 
 L<http://par.perl.org/> is the official PAR website.  You can write
 to the mailing list at E<lt>par@perl.orgE<gt>, or send an empty mail to
@@ -860,7 +865,7 @@ Please submit bug reports to E<lt>bug-par@rt.cpan.orgE<gt>.
 =head1 COPYRIGHT
 
 Copyright 2002, 2003, 2004, 2005, 2006 by Audrey Tang
-E<lt>autrijus@autrijus.orgE<gt>.
+E<lt>cpan@audreyt.orgE<gt>.
 
 Neither this program nor the associated L<parl> program impose any
 licensing restrictions on files generated by their execution, in
